@@ -124,7 +124,7 @@ class References(raw_binding.References):
         return ReferencesIterator(self)
         
     def __len__(self):
-        return len(self.reference.orderedContent())
+        return len(self.reference)
     
     def __getitem__(self, key):
         content = self.reference.orderedContent()
@@ -165,59 +165,65 @@ class Reference(raw_binding.Reference):
          
         self._payload = {}
         
-        m = re_reference.match(self.value())
-        
-        if m:
-            self.label = m.group(2)
-            self.type = m.group(1)
-            content = m.group(3)
+        if len(args) == 1:
+            self.reset()
+            self.append(args[0])
             
-            # Parsing content
+        if self.value():
             
-            section = 0
+            m = re_reference.match(self.value())
             
-            current_key = ''
-            current_value = ''
-                        
-             
-            level = 0
-                     
-            for c in content:
-
-                if c == '=' and level == 0:
-                    if section == 0:
-                        section = 1
-                        continue
-                elif c == ',' and level == 0:
-                    if section == 1:
-                        section = 2
-                        continue
-                elif c == '{':
-                    level += 1
-                elif c == '}':
-                    level -= 1
-                    
+            if m:
+                self.label = m.group(2)
+                self.type = m.group(1)
+                content = m.group(3)
                 
-                if section == 0:
-                    current_key += c
-                if section == 1:
-                    current_value += c
-                if section == 2:
-                    key = current_key.strip()
-                    value = current_value.strip()
-                    
-                    if value.startswith('{') and value.endswith('}'):
-                        value = value.strip('{').strip('}')
+                # Parsing content
+                
+                section = 0
+                
+                current_key = ''
+                current_value = ''
+                            
+                 
+                level = 0
+                         
+                for c in content:
+
+                    if c == '=' and level == 0:
+                        if section == 0:
+                            section = 1
+                            continue
+                    elif c == ',' and level == 0:
+                        if section == 1:
+                            section = 2
+                            continue
+                    elif c == '{':
+                        level += 1
+                    elif c == '}':
+                        level -= 1
                         
-                    setattr(self, key, value)
-                    self._payload[key] = value
                     
-                    current_key   = ''
-                    current_value = ''
-                    level = 0
-                    section = 0
-        else:
-            raise ValueError('Unable to parse reference:\n{}\n'.format(self.value()))
+                    if section == 0:
+                        current_key += c
+                    if section == 1:
+                        current_value += c
+                    if section == 2:
+                        key = current_key.strip()
+                        value = current_value.strip()
+                        
+                        if value.startswith('{') and value.endswith('}'):
+                            value = value[1:-1]
+                            
+                        setattr(self, key, value)
+                        self._payload[key] = value
+                        
+                        current_key   = ''
+                        current_value = ''
+                        level = 0
+                        section = 0
+            else:
+                raise ValueError('Unable to parse reference:\n{}\n'.format(self.value()))
     
     def payload(self):
         return self._payload
@@ -228,7 +234,16 @@ class Reference(raw_binding.Reference):
         
     def bibtex(self):
         s = '@{}{{{},\n'.format(self.type, self.label)
-        for k,v in vars(self).items():
+        for k,v in self._payload.items():
+            if k not in ['label','type','id']:
+                s += '\t{} = {{{}}},\n'.format(k,v)
+        s += '}'
+        
+        return s
+        
+    def textual(self):
+        s = '@{}{{{},\n'.format(self.type, self.label)
+        for k,v in self._payload.items():
             if k not in ['label','type','id']:
                 s += '\t{} = {{{}}},\n'.format(k,v)
         s += '}'
@@ -257,6 +272,7 @@ class Process(raw_binding.Process):
         return ProcessIterator(self)
     
     def __len__(self):
+    
         self._initialize()
         return len(self._data)
     
@@ -269,7 +285,19 @@ class Process(raw_binding.Process):
         self._initialize()
         return self._data
     
-            
+    def get_reactants(self):
+        return tuple(r for r in self.reactants.orderedContent())
+    
+    def get_products(self, channel = 0):
+        
+        if len(self.products) == 0 and channel == 0:
+            return get_reactants()
+        else:
+            return tuple(p for p in self.products.orderedContent()[channel])
+        
+    def get_channels(self):
+        return { i : p.weigth for i, p in enumerate(self.products.orderedContent()) }
+     
     def get_reaction(self):
         s  = ' + '.join(str(r.value) for r in self.reactants.orderedContent())
         s += ' → '
