@@ -1,7 +1,7 @@
 # zcross/raw/binding.py
 # -*- coding: utf-8 -*-
 # PyXB bindings for NM:626ec537dfcf4e27e1a94ab21ad8ef1c6da8dfdf
-# Generated 2021-11-01 21:23:02.278344 by PyXB version 1.2.6 using Python 3.7.3.final.0
+# Generated 2022-09-18 14:47:55.458334 by PyXB version 1.2.6 using Python 3.7.3.final.0
 # Namespace https://zcross.net
 
 from __future__ import unicode_literals
@@ -14,7 +14,7 @@ import pyxb.utils.domutils
 import sys
 import pyxb.utils.six as _six
 # Unique identifier for bindings created at the same time
-_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:218166ca-3b49-11ec-9fa1-50eb711e81f1')
+_GenerationUID = pyxb.utils.utility.UniqueIdentifier('urn:uuid:bbf8c4f0-3747-11ed-9528-50eb711e81f1')
 
 # Version of PyXB used to generate the bindings
 _PyXBVersion = '1.2.6'
